Function make_metal
pub fn make_metal<'a>(
backend: &Handle<GrMtlBackendContext>,
options: impl Into<Option<&'a ContextOptions>>,
) -> Option<RCHandle<GrDirectContext>>Expand description
Makes a DirectContext which uses Metal as the backend. The mtl::BackendContext contains a
MTLDevice and MTLCommandQueue which should be used by the backend. These objects must
have their own ref which will be released when the mtl::BackendContext is destroyed.
Ganesh will take its own ref on the objects which will be released when the DirectContext
is destroyed.